@@ -3,7 +3,7 @@
  *  BlueZ - Bluetooth protocol stack for Linux
  *
  *  Copyright (C) 2002-2003  Maxim Krasnyansky <maxk@qualcomm.com>
- *  Copyright (C) 2002-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2002-2009  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -56,7 +56,8 @@ static void sig_alarm(int sig)
 static int w4_str(int fd, char *str)
 {
 	char buf[40];
-	int  r, len = 0;
+	unsigned len = 0;
+	int r;
 	
 	while (1) {
 		r = read(fd, buf + len, sizeof(buf) - len - 1);
