@@ -3,7 +3,7 @@
  *  BlueZ - Bluetooth protocol stack for Linux
  *
  *  Copyright (C) 2006-2007  Nokia Corporation
- *  Copyright (C) 2004-2008  Marcel Holtmann <marcel@holtmann.org>
+ *  Copyright (C) 2004-2009  Marcel Holtmann <marcel@holtmann.org>
  *
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -203,7 +203,7 @@ int read_on_mode(const char *src, char *mode, int length)
 	return 0;
 }
 
-int write_local_name(bdaddr_t *bdaddr, char *name)
+int write_local_name(bdaddr_t *bdaddr, const char *name)
 {
 	char filename[PATH_MAX + 1], str[249];
 	int i;
@@ -570,6 +570,11 @@ int read_link_key(bdaddr_t *local, bdaddr_t *peer, unsigned char *key, uint8_t *
 	if (!str)
 		return -ENOENT;
 
+	if (!key) {
+		free(str);
+		return 0;
+	}
+
 	memset(tmp, 0, sizeof(tmp));
 	for (i = 0; i < 16; i++) {
 		memcpy(tmp, str + (i * 2), 2);
@@ -808,7 +813,7 @@ int store_record(const gchar *src, const gchar *dst, sdp_record_t *rec)
 	char filename[PATH_MAX + 1], key[28];
 	sdp_buf_t buf;
 	int err, size, i;
-	char *pdata, *str;
+	char *str;
 
 	create_name(filename, PATH_MAX, STORAGEDIR, src, "sdp");
 
@@ -819,7 +824,6 @@ int store_record(const gchar *src, const gchar *dst, sdp_record_t *rec)
 	if (sdp_gen_record_pdu(rec, &buf) < 0)
 		return -1;
 
-	pdata = (char *)buf.data;
 	size = buf.data_size;
 
 	str = g_malloc0(size*2+1);
@@ -847,8 +851,8 @@ sdp_record_t *record_from_string(const gchar *str)
 
 	tmp[2] = 0;
 	for (i = 0; i < size; i++) {
-		 memcpy(tmp, str + (i * 2), 2);
-		 pdata[i] = (uint8_t) strtol(tmp, NULL, 16);
+		memcpy(tmp, str + (i * 2), 2);
+		pdata[i] = (uint8_t) strtol(tmp, NULL, 16);
 	}
 
 	rec = sdp_extract_pdu(pdata, size, &len);
@@ -1068,8 +1072,8 @@ int read_device_id(const gchar *srcaddr, const gchar *dstaddr,
 	if (err) {
 		/* FIXME: We should try EIR data if we have it, too */
 
-		/* If we don't have the data, we don't want to go
-		   through the above search every time. */
+		/* If we don't have the data, we don't want to go through the
+		 * above search every time. */
 		lsource = 0xffff;
 		lvendor = 0x0000;
 		lproduct = 0x0000;
